﻿using Falcon.SugarApi.Encryption;

namespace Falcon.SugarApi.JWT
{
    /// <summary>
    /// 使用AES算法生成Token
    /// </summary>
    public class AESTokenbuilder : IJwtTokenBuilder
    {
        /// <summary>
        /// AES加密算法
        /// </summary>
        public IAESEncryption AES { get; set; }
        /// <summary>
        /// jwt生成参数
        /// </summary>
        public JwtContext Jwt { get; }

        /// <summary>
        /// 构造AES的Token
        /// </summary>
        /// <param name="config">AES参数</param>
        /// <param name="jwt">jwt生成参数</param>
        public AESTokenbuilder(AESConfig config, JwtContext jwt) {
            Jwt = jwt;
            AES = new AESProvider(config);
        }

        /// <inheritdoc>/
        public LoginUserInfo GetPlayload(string token) {
            token.ThrowNullExceptionWhenNull();
            return this.AES.Decrypt<LoginUserInfo>(Jwt.SecKey, token);
        }

        /// <inheritdoc>/
        public string GetToken(LoginUserInfo playload) {
            playload.ThrowNullExceptionWhenNull();
            return this.AES.Encrypt(Jwt.SecKey, playload);
        }
    }

}
