﻿using System;

namespace Falcon.SugarApi.JWT
{
    /// <summary>
    /// JwtTokenBuilder扩展
    /// </summary>
    public static class JwtTokenBuilderExtend
    {
        /// <summary>
        /// 尝试获取Token
        /// </summary>
        /// <param name="builder">生成器</param>
        /// <param name="userInfo">用户信息</param>
        /// <param name="token">生成的token</param>
        /// <param name="exception">失败异常</param>
        /// <returns>成功True，失败False</returns>
        public static bool TryGetToken(this JwtTokenBuilder builder, LoginUserInfo userInfo, out string? token, out Exception? exception) {
            try {
                token = builder.GetToken(userInfo);
                exception = null;
                return true;
            }
            catch (Exception ex) {
                token = null;
                exception = ex;
                return false;
            }
        }

        /// <summary>
        /// 尝试获取用户信息
        /// </summary>
        /// <param name="builder">jwt创建器</param>
        /// <param name="token">token</param>
        /// <param name="userInfo">用户信息</param>
        /// <param name="exception">异常</param>
        /// <returns>True成功，False失败</returns>
        public static bool TryGetPlayload(this JwtTokenBuilder builder, string token, out LoginUserInfo? userInfo, out Exception? exception) {
            try {
                userInfo = builder.GetPlayload(token);
                exception = null;
                return true;
            }
            catch (Exception ex) {
                userInfo = null;
                exception = ex;
                return false;
            }
        }
    }
}
